histore package
===============

.. automodule:: histore
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 3

   histore.archive
   histore.cli
   histore.document
   histore.tests

Submodules
----------

.. toctree::
   :maxdepth: 3

   histore.config
   histore.key
   histore.util
   histore.version
